@@ -83,15 +83,17 @@ func (s *mcpServer) registerToolsFromCommands() {
 			continue
 		}
 
-		// Skip commands that should not be exposed via MCP
-		if cmd.Annotations != nil {
-			if val, exists := cmd.Annotations[mcpannotations.Interactive]; exists && val == "true" {
-				continue
-			}
-			// Skip explicitly excluded commands (credentials/secrets handling)
-			if val, exists := cmd.Annotations[mcpannotations.Exclude]; exists && val == "true" {
-				continue
-			}
+		// Skip commands that don't have explicit MCP annotations (require opt-in)
+		if !mcpannotations.HasAnnotation(cmd.Annotations) {
+			continue
+		}
+
+		// Skip commands marked as interactive or excluded
+		if val := cmd.Annotations[mcpannotations.Interactive]; val == "true" {
+			continue
+		}
+		if val := cmd.Annotations[mcpannotations.Exclude]; val == "true" {
+			continue
 		}
 
 		toolName := "glab_" + strings.Join(path, "_")
@@ -351,17 +353,32 @@ func (s *mcpServer) createCommandHandler(cmdPath []string, cmd *cobra.Command) m
 			}, nil
 		}
 
-		// Process output with rune-based limiting and metadata
-		processedOutput, metadata := s.processOutput(output, config)
+		// Process output with rune-based limiting
+		processedOutput := s.processOutput(output, config)
 
-		// Return the result with clean content and structured metadata
+		// Try to parse as JSON and return structured content for better LLM parsing
+		var structuredData any
+		if err := json.Unmarshal([]byte(processedOutput), &structuredData); err == nil {
+			// Successfully parsed JSON - return both content and structured content
+			// This follows MCP spec: "For backwards compatibility, a tool that returns
+			// structured content SHOULD also return the serialized JSON in a TextContent block"
+			return &mcp.CallToolResult{
+				Content: []mcp.Content{
+					&mcp.TextContent{
+						Text: processedOutput,
+					},
+				},
+				StructuredContent: structuredData,
+			}, nil
+		}
+
+		// Not JSON or parse failed - return as plain text
 		return &mcp.CallToolResult{
 			Content: []mcp.Content{
 				&mcp.TextContent{
 					Text: processedOutput,
 				},
 			},
-			Meta: metadata,
 		}, nil
 	}
 }
@@ -372,8 +389,8 @@ type responseConfig struct {
 	Offset int
 }
 
-// processOutput handles rune-based output limiting and generates metadata
-func (s *mcpServer) processOutput(output string, config responseConfig) (string, map[string]any) {
+// processOutput handles rune-based output limiting
+func (s *mcpServer) processOutput(output string, config responseConfig) string {
 	// Convert to runes for Unicode-safe processing
 	runes := []rune(output)
 	totalSize := len(runes)
@@ -396,32 +413,7 @@ func (s *mcpServer) processOutput(output string, config responseConfig) (string,
 		processedRunes = runes[start:end]
 	}
 
-	// Create comprehensive metadata
-	truncated := (start > 0 || end < totalSize)
-	metadata := map[string]any{
-		"pagination": map[string]any{
-			"total_size":   totalSize,
-			"limit":        config.Limit,
-			"offset":       config.Offset,
-			"actual_start": start,
-			"actual_end":   end,
-			"actual_size":  len(processedRunes),
-			"truncated":    truncated,
-		},
-	}
-
-	// Add helpful navigation hints for AI
-	if truncated {
-		metadata["pagination"].(map[string]any)["navigation_hints"] = map[string]any{
-			"to_beginning": 0,
-			"to_end":       totalSize - config.Limit,
-			"next_page":    end,
-			"prev_page":    start - config.Limit,
-		}
-		metadata["pagination"].(map[string]any)["usage_guide"] = "To navigate: use 'to_end' offset to jump to end where failures typically occur, 'next_page' for next section, or calculate custom offset. Example: for logs that end with errors, use offset = total_size - limit."
-	}
-
-	return string(processedRunes), metadata
+	return string(processedRunes)
 }
 
 // convertParamsToArgs converts MCP JSON parameters to command line arguments and extracts response config
@@ -524,6 +516,31 @@ func (s *mcpServer) convertParamsToArgs(params map[string]any, cmd *cobra.Comman
 		}
 	}
 
+	// Auto-enable JSON output for commands that support it (better for LLM parsing)
+	// Only add if user hasn't already specified an output format via MCP params
+	if outputFlag := cmd.Flags().Lookup("output"); outputFlag != nil {
+		// Check if output flag was already provided by user in their MCP parameters
+		// (which would have been processed into args above)
+		// Users could specify either long form ("output") or short form ("o")
+		outputAlreadySet := false
+		for _, arg := range args {
+			// Check for all possible forms:
+			// - "--output" or "--output=" (long form)
+			// - "--o" or "--o=" (short form, our code adds -- prefix)
+			// - "-o" (short form, for robustness)
+			if arg == "--output" || strings.HasPrefix(arg, "--output=") ||
+				arg == "--o" || strings.HasPrefix(arg, "--o=") ||
+				arg == "-o" {
+				outputAlreadySet = true
+				break
+			}
+		}
+
+		if !outputAlreadySet {
+			args = append(args, "--output", "json")
+		}
+	}
+
 	// Add positional arguments at the end
 	args = append(args, positionals...)
 
@@ -566,6 +583,6 @@ func (s *mcpServer) isDestructiveCommand(cmd *cobra.Command) bool {
 		}
 	}
 
-	// Default to destructive for safety if no annotation found (should not happen for executable commands)
+	// Default to destructive for safety if no annotation found (should not happen - unannotated commands are filtered out)
 	return true
 }
