@@ -4,8 +4,10 @@ import (
 	"fmt"
 
 	"github.com/spf13/cobra"
+
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/commands/mr/mrutils"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 )
 
 func NewCmdApprovers(f cmdutils.Factory) *cobra.Command {
@@ -15,6 +17,9 @@ func NewCmdApprovers(f cmdutils.Factory) *cobra.Command {
 		Long:    ``,
 		Aliases: []string{},
 		Args:    cobra.MaximumNArgs(1),
+		Annotations: map[string]string{
+			mcpannotations.Safe: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			client, err := f.GitLabClient()
 			if err != nil {
@@ -23,7 +28,7 @@ func NewCmdApprovers(f cmdutils.Factory) *cobra.Command {
 
 			// Obtain the MR from the positional arguments, but allow users to find approvers for
 			// merge requests in any valid state
-			mr, repo, err := mrutils.MRFromArgs(f, args, "any")
+			mr, repo, err := mrutils.MRFromArgs(cmd.Context(), f, args, "any")
 			if err != nil {
 				return err
 			}
